pilas.interfaz

Package pilas :: Package interfaz |
[hide private]
[frames] | no frames]

# Source Code for Package pilas.interfaz

     1  # -*- encoding: utf-8 -*-
     2  # pilas engine - a video game framework.
     3  #
     4  # copyright 2010 - hugo ruscitti
     5  # license: lgplv3 (see http://www.gnu.org/licenses/lgpl.html)
     6  #
     7  # website - http://www.pilas-engine.com.ar
     8
     9
    10  from deslizador import Deslizador
    11  from selector import Selector
    12  from ingreso_de_texto import IngresoDeTexto
    13  from lista_seleccion import ListaSeleccion
    14  from boton import Boton
    15